@@ -1,6 +1,6 @@
 pub mod common;
 pub mod info;
-pub mod module;
+pub mod module_impl;
 pub mod remote_indv_r_storage;
 pub mod ticket;
 pub mod veda_backend;
